@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# namcap tests - arrays
+# namcap tests - extravars
 # Copyright (C) 2011 Rémy Oudompheng <remy@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
@@ -19,19 +19,10 @@
 #   USA
 # 
 
-import os
-import unittest
-import tempfile
-import shutil
+from Namcap.tests.pkgbuild_test import PkgbuildTest
+import Namcap.rules.extravars
 
-import pacman
-import valid_pkgbuilds
-
-import Namcap.extravars
-
-EMPTY_RESULT = [ [] , [] , [] ]
-
-class ExtravarsTest(unittest.TestCase):
+class ExtravarsTest(PkgbuildTest):
 	pkgbuild1 = """
 # Maintainer: Arch Linux <archlinux@example.com>
 # Contributor: Arch Linux <archlinux@example.com>
@@ -65,35 +56,20 @@ package() {
   make DESTDIR="${pkgdir}" install
 }
 """
-	def setUp(self):
-		self.rule = Namcap.extravars.package()
-		self.tmpdir = tempfile.mkdtemp()
-		self.tmpname = os.path.join(self.tmpdir, "PKGBUILD")
 
-	def tearDown(self):
-		shutil.rmtree(self.tmpdir)
+	test_valid = PkgbuildTest.valid_tests
 
-	def run_on_pkg(self, p):
-		with open(self.tmpname, 'w') as f:
-			f.write(p)
-		pkginfo = pacman.load(self.tmpname)
-		return self.rule.analyze(pkginfo, self.tmpname)
-
-	def test_valid(self):
-		# Valid PKGBUILDS
-		for p in valid_pkgbuilds.all_pkgbuilds:
-			ret = self.run_on_pkg(p)
-			self.assertEqual(ret, EMPTY_RESULT)
+	def preSetUp(self):
+		self.rule = Namcap.rules.extravars.package
 
 	def test_example1(self):
-		# Example 1
-		ret = self.run_on_pkg(self.pkgbuild1)
-		self.assertEqual(ret[0], [])
-		self.assertEqual(set(ret[1]), set([
+		"PKGBUILD with custom variables without underscore"
+		r = self.run_on_pkg(self.pkgbuild1)
+		self.assertEqual(r.errors, [])
+		self.assertEqual(set(r.warnings), set([
 			("extra-var-begins-without-underscore %s", "mycustomvar"),
 			("extra-var-begins-without-underscore %s", "hello")
 		]))
-		self.assertEqual(ret[2], [])
-
+		self.assertEqual(r.infos, [])
 
 # vim: set ts=4 sw=4 noet:
